@@ -1,14 +1,13 @@
 import os
-import shutil
 import tempfile
 import uuid
 from pathlib import Path
 
+from flet_runtime.utils import copy_tree, get_package_bin_dir
+
 
 def get_flet_bin_path():
-    bin_path = os.path.abspath(
-        os.path.join(os.path.dirname(__file__), os.pardir, "bin")
-    )
+    bin_path = get_package_bin_dir()
     if not os.path.exists(bin_path):
         return None
     return bin_path
@@ -21,5 +20,5 @@ def copy_flet_bin():
 
     # create temp bin dir
     temp_bin_dir = Path(tempfile.gettempdir()).joinpath(str(uuid.uuid4()))
-    shutil.copytree(bin_path, str(temp_bin_dir))
+    copy_tree(bin_path, str(temp_bin_dir))
     return str(temp_bin_dir)
