@@ -1,26 +1,29 @@
 """Provide the current Flet version."""
 
-
 import os
 import subprocess as sp
 from pathlib import Path
 
 import flet
-from flet.utils import is_windows, which
+import flet_core.version
+from flet_runtime.utils import is_mobile, is_windows, which
 
-# this value will be replaced by CI
-version = ""
+version = flet_core.version.version
 
 
 def update_version():
     """Return the current version or default."""
     working = Path().absolute()
     os.chdir(Path(flet.__file__).absolute().parent)
-    in_repo = which("git.exe" if is_windows() else "git") and sp.run(
-        ["git", "status"],
-        capture_output=True,
-        text=True,
-    ).stdout.startswith("On branch ")
+    in_repo = (
+        which("git.exe" if is_windows() else "git")
+        and sp.run(
+            ["git", "status"],
+            capture_output=True,
+            text=True,
+        ).returncode
+        == 0
+    )
 
     if in_repo:
         # NOTE: this may break if there is a tag name starting with
@@ -51,5 +54,5 @@ def update_version():
     return version
 
 
-if not version:
+if not version and not is_mobile():
     version = update_version()
